@@ -1,6 +1,4 @@
-from __future__ import absolute_import, unicode_literals
-
-__all__ = ['APIWrapper']
+__all__ = ["APIWrapper"]
 
 
 class APIWrapper(object):
@@ -15,7 +13,7 @@ class APIWrapper(object):
     def __init__(self, connection, executor):
         self._conn = connection
         self._executor = executor
-        self._is_transaction = self.context == 'transaction'
+        self._is_transaction = self.context == "transaction"
 
     @property
     def tenant_name(self):
@@ -62,7 +60,6 @@ class APIWrapper(object):
         """
         return self._conn.topic_persistence
 
-
     @property
     def username(self):
         """Return the username.
@@ -82,7 +79,7 @@ class APIWrapper(object):
         """
         return self._executor.context
 
-    def _execute(self, request, response_handler):
+    def _execute(self, request, response_handler, custom_prefix=None):
         """Execute an API per execution context.
 
         :param request: HTTP request.
@@ -92,4 +89,6 @@ class APIWrapper(object):
         :return: API execution result.
         :rtype: str | unicode | bool | int | list | dict
         """
-        return self._executor.execute(request, response_handler)
+        return self._executor.execute(
+            request, response_handler, custom_prefix=custom_prefix
+        )
