@@ -1,27 +1,18 @@
 from __future__ import absolute_import, unicode_literals
 
-from six import string_types
-
 from collections import OrderedDict
 from uuid import uuid4
 
-from c8.exceptions import (
-    AsyncExecuteError,
-    BatchStateError,
-    BatchExecuteError,
-)
-from c8.job import (
-    AsyncJob,
-    BatchJob,
-)
+from c8.exceptions import AsyncExecuteError, BatchExecuteError, BatchStateError
+from c8.job import AsyncJob, BatchJob
 from c8.request import Request
 from c8.response import Response
 from c8.utils import suppress_warning
 
 __all__ = [
-    'DefaultExecutor',
-    'AsyncExecutor',
-    'BatchExecutor',
+    "DefaultExecutor",
+    "AsyncExecutor",
+    "BatchExecutor",
 ]
 
 
@@ -34,6 +25,7 @@ class Executor(object):  # pragma: no cover
     :param connection: HTTP connection.
     :type connection: c8.connection.Connection
     """
+
     context = None
 
     def __init__(self, connection):
@@ -58,23 +50,25 @@ class DefaultExecutor(Executor):
     :param connection: HTTP connection.
     :type connection: c8.connection.Connection
     """
-    context = 'default'
+
+    context = "default"
 
     def __init__(self, connection):
         super(DefaultExecutor, self).__init__(connection)
 
-    def execute(self, request, response_handler):
+    def execute(self, request, response_handler, custom_prefix=None):
         """Execute an API request and return the result.
 
         :param request: HTTP request.
         :type request: c8.request.Request
         :param response_handler: HTTP response handler.
         :type response_handler: callable
+        :param custom_prefix: Custom url-path value
+        :type custom_prefix: str
         :return: API execution result.
         :rtype: str | unicode | bool | int | list | dict
         """
-
-        response = self._conn.send_request(request)
+        response = self._conn.send_request(request, custom_prefix=custom_prefix)
         return response_handler(response)
 
 
@@ -89,7 +83,8 @@ class AsyncExecutor(Executor):
         results are stored on server.
     :type return_result: bool
     """
-    context = 'async'
+
+    context = "async"
 
     def __init__(self, connection, return_result):
         super(AsyncExecutor, self).__init__(connection)
@@ -107,9 +102,9 @@ class AsyncExecutor(Executor):
         :rtype: c8.job.AsyncJob | None
         """
         if self._return_result:
-            request.headers['x-c8-async'] = 'store'
+            request.headers["x-c8-async"] = "store"
         else:
-            request.headers['x-c8-async'] = 'true'
+            request.headers["x-c8-async"] = "true"
 
         resp = self._conn.send_request(request)
         if not resp.is_success:
@@ -117,7 +112,7 @@ class AsyncExecutor(Executor):
         if not self._return_result:
             return None
 
-        job_id = resp.headers['x-c8-async-id']
+        job_id = resp.headers["x-c8-async-id"]
         return AsyncJob(self._conn, job_id, response_handler)
 
 
@@ -132,7 +127,8 @@ class BatchExecutor(Executor):
         client-side.
     :type return_result: bool
     """
-    context = 'batch'
+
+    context = "batch"
 
     def __init__(self, connection, return_result):
         super(BatchExecutor, self).__init__(connection)
@@ -166,7 +162,7 @@ class BatchExecutor(Executor):
             committed.
         """
         if self._committed:
-            raise BatchStateError('batch already committed')
+            raise BatchStateError("batch already committed")
 
         job = BatchJob(response_handler)
         self._queue[job.id] = (request, job)
@@ -187,7 +183,7 @@ class BatchExecutor(Executor):
         :raise c8.exceptions.BatchExecuteError: If commit fails.
         """
         if self._committed:
-            raise BatchStateError('batch already committed')
+            raise BatchStateError("batch already committed")
 
         self._committed = True
 
@@ -200,22 +196,21 @@ class BatchExecutor(Executor):
         # Buffer for building the batch request payload
         buffer = []
         for req, job in self._queue.values():
-            buffer.append('--{}'.format(boundary))
-            buffer.append('Content-Type: application/x-c8-batchpart')
-            buffer.append('Content-Id: {}'.format(job.id))
-            buffer.append('\r\n{}'.format(req))
-        buffer.append('--{}--'.format(boundary))
+            buffer.append("--{}".format(boundary))
+            buffer.append("Content-Type: application/x-c8-batchpart")
+            buffer.append("Content-Id: {}".format(job.id))
+            buffer.append("\r\n{}".format(req))
+        buffer.append("--{}--".format(boundary))
 
         request = Request(
-            method='post',
-            endpoint='/batch',
+            method="post",
+            endpoint="/batch",
             headers={
-                'Content-Type':
-                    'multipart/form-data; boundary={}'.format(boundary)
+                "Content-Type": "multipart/form-data; boundary={}".format(boundary)
             },
-            data='\r\n'.join(buffer)
+            data="\r\n".join(buffer),
         )
-        with suppress_warning('requests.packages.urllib3.connectionpool'):
+        with suppress_warning("requests.packages.urllib3.connectionpool"):
             resp = self._conn.send_request(request)
 
         if not resp.is_success:
@@ -224,20 +219,21 @@ class BatchExecutor(Executor):
         if not self._return_result:
             return None
 
-        raw_resps = resp.raw_body.split('--{}'.format(boundary))[1:-1]
+        raw_resps = resp.raw_body.split("--{}".format(boundary))[1:-1]
         if len(self._queue) != len(raw_resps):
             raise BatchStateError(
-                'expecting {} parts in batch response but got {}'.format(
-                    len(self._queue), len(raw_resps))
+                "expecting {} parts in batch response but got {}".format(
+                    len(self._queue), len(raw_resps)
+                )
             )
         for raw_resp in raw_resps:
             # Parse and breakdown the batch response body
-            resp_parts = raw_resp.strip().split('\r\n')
+            resp_parts = raw_resp.strip().split("\r\n")
             raw_content_id = resp_parts[1]
             raw_body = resp_parts[-1]
             raw_status = resp_parts[3]
-            job_id = raw_content_id.split(' ')[1]
-            _, status_code, status_text = raw_status.split(' ', 2)
+            job_id = raw_content_id.split(" ")[1]
+            _, status_code, status_text = raw_status.split(" ", 2)
 
             # Update the corresponding batch job
             queued_req, queued_job = self._queue[job_id]
@@ -247,8 +243,8 @@ class BatchExecutor(Executor):
                 headers={},
                 status_code=int(status_code),
                 status_text=status_text,
-                raw_body=raw_body
+                raw_body=raw_body,
             )
-            queued_job._status = 'done'
+            queued_job._status = "done"
 
         return self.jobs
