@@ -1029,7 +1029,7 @@ class Fabric(APIWrapper):
             operation_timeout_seconds,
         )
 
-    def streams(self, local=False):
+    def streams(self, local=None):
         """Get list of all streams under given fabric
 
         :returns: List of streams under given fabric.
@@ -1042,6 +1042,9 @@ class Fabric(APIWrapper):
         elif local is True:
             url_endpoint = "/streams?global=false"
 
+        elif local is None:
+            url_endpoint = "/streams"
+
         request = Request(method="get", endpoint=url_endpoint)
 
         def response_handler(resp):
